@@ -20,6 +20,7 @@
 
 #include "config.h"
 
+#include "gkd-dbus.h"
 #include "gkd-secret-dispatch.h"
 #include "gkd-secret-error.h"
 #include "gkd-secret-secret.h"
@@ -39,7 +40,6 @@
 enum {
 	PROP_0,
 	PROP_CALLER,
-	PROP_CALLER_EXECUTABLE,
 	PROP_OBJECT_PATH,
 	PROP_SERVICE
 };
@@ -51,7 +51,6 @@ struct _GkdSecretSession {
 	gchar *object_path;
 	GkdSecretService *service;
 	GkdExportedSession *skeleton;
-	gchar *caller_exec;
 	gchar *caller;
 
 	/* While negotiating with a prompt, set to private key */
@@ -208,7 +207,7 @@ aes_negotiate (GkdSecretSession *self,
 		return FALSE;
 	}
 
-	input = g_variant_get_fixed_array (input_variant, &n_input, sizeof (guint8));
+	input = g_variant_get_fixed_array (input_variant, &n_input, sizeof (guchar));
 	ret = aes_derive_key (session, priv, input, n_input, &key);
 
 	gck_object_destroy (priv, NULL, NULL);
@@ -225,11 +224,9 @@ aes_negotiate (GkdSecretSession *self,
 	take_session_key (self, key, CKM_AES_CBC_PAD);
 
 	if (output_variant != NULL) {
-		GVariantBuilder builder;
-
-		g_variant_builder_init (&builder, G_VARIANT_TYPE ("ay"));
-		g_variant_builder_add (&builder, "y", (const gchar *) output);
-		*output_variant = g_variant_new_variant (g_variant_builder_end (&builder));
+		*output_variant = g_variant_new_variant (g_variant_new_fixed_array (G_VARIANT_TYPE_BYTE,
+										    output, n_output,
+										    sizeof (guchar)));
 	}
 
 	if (result != NULL) {
@@ -290,6 +287,9 @@ session_method_close (GkdExportedSession *skeleton,
 		      GDBusMethodInvocation *invocation,
 		      GkdSecretSession *self)
 {
+	if (!gkd_dbus_invocation_matches_caller (invocation, self->caller))
+		return FALSE;
+
 	gkd_secret_service_close_session (self->service, self);
 	gkd_exported_session_complete_close (skeleton, invocation);
 
@@ -370,9 +370,6 @@ gkd_secret_session_finalize (GObject *obj)
 	g_assert (!self->service);
 	g_assert (!self->key);
 
-	g_free (self->caller_exec);
-	self->caller_exec = NULL;
-
 	g_free (self->caller);
 	self->caller = NULL;
 
@@ -390,10 +387,6 @@ gkd_secret_session_set_property (GObject *obj, guint prop_id, const GValue *valu
 		g_return_if_fail (!self->caller);
 		self->caller = g_value_dup_string (value);
 		break;
-	case PROP_CALLER_EXECUTABLE:
-		g_return_if_fail (!self->caller_exec);
-		self->caller_exec = g_value_dup_string (value);
-		break;
 	case PROP_SERVICE:
 		g_return_if_fail (!self->service);
 		self->service = g_value_get_object (value);
@@ -417,9 +410,6 @@ gkd_secret_session_get_property (GObject *obj, guint prop_id, GValue *value,
 	case PROP_CALLER:
 		g_value_set_string (value, gkd_secret_session_get_caller (self));
 		break;
-	case PROP_CALLER_EXECUTABLE:
-		g_value_set_string (value, gkd_secret_session_get_caller_executable (self));
-		break;
 	case PROP_OBJECT_PATH:
 		g_value_set_pointer (value, self->object_path);
 		break;
@@ -447,10 +437,6 @@ gkd_secret_session_class_init (GkdSecretSessionClass *klass)
 		g_param_spec_string ("caller", "Caller", "DBus caller name",
 				     NULL, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY ));
 
-	g_object_class_install_property (gobject_class, PROP_CALLER_EXECUTABLE,
-		g_param_spec_string ("caller-executable", "Caller Executable", "Executable of caller",
-				     NULL, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY ));
-
 	g_object_class_install_property (gobject_class, PROP_OBJECT_PATH,
 		g_param_spec_pointer ("object-path", "Object Path", "DBus Object Path",
 				      G_PARAM_READABLE));
@@ -584,13 +570,6 @@ gkd_secret_session_get_caller (GkdSecretSession *self)
 	return self->caller;
 }
 
-const gchar*
-gkd_secret_session_get_caller_executable (GkdSecretSession *self)
-{
-	g_return_val_if_fail (GKD_SECRET_IS_SESSION (self), NULL);
-	return self->caller_exec;
-}
-
 GckSession*
 gkd_secret_session_get_pkcs11_session (GkdSecretSession *self)
 {
