@@ -32,7 +32,6 @@
 #include "pkcs11/gnome2-store/gkm-gnome2-store.h"
 #include "pkcs11/xdg-store/gkm-xdg-store.h"
 
-#include "gpg-agent/gkd-gpg-agent.h"
 #include "ssh-agent/gkd-ssh-agent.h"
 
 #include <string.h>
@@ -52,7 +51,6 @@ pkcs11_daemon_cleanup (gpointer unused)
 
 	gkd_ssh_agent_uninitialize ();
 	gkm_rpc_layer_uninitialize ();
-	gkd_gpg_agent_uninitialize ();
 	rv = (pkcs11_roof->C_Finalize) (NULL);
 
 	if (rv != CKR_OK)
@@ -115,8 +113,7 @@ gkd_pkcs11_initialize (void)
 
 	egg_cleanup_register (pkcs11_daemon_cleanup, NULL);
 
-	ret = gkd_gpg_agent_initialize (pkcs11_roof) &&
-	      gkd_ssh_agent_initialize (pkcs11_roof) &&
+	ret = gkd_ssh_agent_initialize (pkcs11_roof) &&
 	      gkm_rpc_layer_initialize (pkcs11_roof);
 
 	return ret;
