@@ -15,8 +15,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   <http://www.gnu.org/licenses/>.
 
    Author: Stef Walter <stef@memberwebs.com>
 */
@@ -55,9 +54,23 @@ typedef enum {
 	EGG_ASN1X_IMPORTS = 19,
 	EGG_ASN1X_NULL = 20,
 	EGG_ASN1X_ENUMERATED = 21,
-	EGG_ASN1X_GENERALSTRING = 27
+	EGG_ASN1X_GENERAL_STRING = 27,
+	EGG_ASN1X_NUMERIC_STRING = 28,
+	EGG_ASN1X_IA5_STRING = 29,
+	EGG_ASN1X_TELETEX_STRING = 30,
+	EGG_ASN1X_PRINTABLE_STRING = 31,
+	EGG_ASN1X_UNIVERSAL_STRING = 32,
+	EGG_ASN1X_BMP_STRING = 33,
+	EGG_ASN1X_UTF8_STRING = 34,
+	EGG_ASN1X_VISIBLE_STRING = 35,
+	EGG_ASN1X_UTC_TIME = 36,
+	EGG_ASN1X_GENERALIZED_TIME = 37,
 } EggAsn1xType;
 
+enum {
+	EGG_ASN1X_NO_STRICT = 0x01,
+} EggAsn1xFlags;
+
 GNode*              egg_asn1x_create                 (const EggAsn1xDef *defs,
                                                       const gchar *type);
 
@@ -68,6 +81,11 @@ GNode*              egg_asn1x_create_and_decode      (const EggAsn1xDef *defs,
                                                       const gchar *type,
                                                       GBytes *data);
 
+GNode*              egg_asn1x_create_and_decode_full (const EggAsn1xDef *defs,
+                                                      const gchar *type,
+                                                      GBytes *data,
+                                                      gint options);
+
 void                egg_asn1x_dump                   (GNode *asn);
 
 void                egg_asn1x_clear                  (GNode *asn);
@@ -75,8 +93,34 @@ void                egg_asn1x_clear                  (GNode *asn);
 gboolean            egg_asn1x_decode                 (GNode *asn,
                                                       GBytes *data);
 
-gboolean            egg_asn1x_decode_no_validate     (GNode *asn,
-                                                      GBytes *data);
+gboolean            egg_asn1x_decode_full            (GNode *asn,
+                                                      GBytes *data,
+                                                      gint options);
+
+void                egg_asn1x_set_any_from           (GNode *node,
+                                                      GNode *from);
+
+gboolean            egg_asn1x_set_any_raw            (GNode *node,
+                                                      GBytes *raw);
+
+gboolean            egg_asn1x_get_any_into           (GNode *node,
+                                                      GNode *into);
+
+gboolean            egg_asn1x_get_any_into_full      (GNode *node,
+                                                      GNode *into,
+                                                      gint options);
+
+GNode *             egg_asn1x_get_any_as             (GNode *node,
+                                                      const EggAsn1xDef *defs,
+                                                      const gchar *type);
+
+GNode *             egg_asn1x_get_any_as_full        (GNode *node,
+                                                      const EggAsn1xDef *defs,
+                                                      const gchar *type,
+                                                      gint options);
+
+GBytes *            egg_asn1x_get_any_raw            (GNode *node,
+                                                      EggAllocator allocator);
 
 gboolean            egg_asn1x_validate               (GNode *asn,
                                                       gboolean strict);
@@ -107,20 +151,20 @@ gboolean            egg_asn1x_set_choice             (GNode *node,
 gboolean            egg_asn1x_get_boolean            (GNode *node,
                                                       gboolean *value);
 
-gboolean            egg_asn1x_set_boolean            (GNode *node,
+void                egg_asn1x_set_boolean            (GNode *node,
                                                       gboolean value);
 
-gboolean            egg_asn1x_set_null               (GNode *node);
+void                egg_asn1x_set_null               (GNode *node);
 
 GQuark              egg_asn1x_get_enumerated         (GNode *node);
 
-gboolean            egg_asn1x_set_enumerated         (GNode *node,
+void                egg_asn1x_set_enumerated         (GNode *node,
                                                       GQuark value);
 
 gboolean            egg_asn1x_get_integer_as_ulong   (GNode *node,
                                                       gulong *value);
 
-gboolean            egg_asn1x_set_integer_as_ulong   (GNode *node,
+void                egg_asn1x_set_integer_as_ulong   (GNode *node,
                                                       gulong value);
 
 GBytes *            egg_asn1x_get_integer_as_raw     (GNode *node);
@@ -139,26 +183,23 @@ void                egg_asn1x_set_integer_as_usg     (GNode *node,
 void                egg_asn1x_take_integer_as_usg    (GNode *node,
                                                       GBytes *value);
 
-GBytes *            egg_asn1x_get_raw_value          (GNode *node);
+GBytes *            egg_asn1x_get_value_raw          (GNode *node);
 
 GBytes *            egg_asn1x_get_element_raw        (GNode *node);
 
-gboolean            egg_asn1x_set_element_raw        (GNode *node,
-                                                      GBytes *value);
-
 guchar*             egg_asn1x_get_string_as_raw      (GNode *node,
                                                       EggAllocator allocator,
                                                       gsize *n_string);
 
-gboolean            egg_asn1x_set_string_as_raw      (GNode *node,
+void                egg_asn1x_set_string_as_raw      (GNode *node,
                                                       guchar *data,
                                                       gsize n_data,
                                                       GDestroyNotify destroy);
 
 GBytes *            egg_asn1x_get_string_as_bytes    (GNode *node);
 
-gboolean            egg_asn1x_set_string_as_bytes    (GNode *node,
-                                                      GBytes *data);
+void                egg_asn1x_set_string_as_bytes    (GNode *node,
+                                                      GBytes *bytes);
 
 GBytes *            egg_asn1x_get_bits_as_raw        (GNode *node,
                                                       guint *n_bits);
@@ -175,7 +216,7 @@ gboolean            egg_asn1x_get_bits_as_ulong      (GNode *node,
                                                       gulong *value,
                                                       guint *n_bits);
 
-gboolean            egg_asn1x_set_bits_as_ulong      (GNode *node,
+void                egg_asn1x_set_bits_as_ulong      (GNode *node,
                                                       gulong value,
                                                       guint n_bits);
 
